==> ttetris-0.1.tar.gz: ttetris-0.1/main.h <==
/****************************************************************
 Project Name: Terminal Tetris
 File Name: main.h
 Description: Լ .
 
 Created:2004. 12. 22  
 RCS-ID: $Id: main.h,v 1.43 2004/06/11 06:22:49 myunggoni Exp $
 Copyright: 2004 (c) by myunggoni
 License: GNU General Public License
 Author: Myung-Gon, Park <myunggoni@users.kldp.net>
 ***************************************************************/
#ifndef MAIN_H
#define MAIN_H

#define MAX_HEIGHT 21 /*  . */
#define MAX_WIDTH 17 /*  ʺ. */
#define START_BLOCKS_X 6 /*    ġ(). */
#define START_BLOCKS_Y 1 /*    ġ(). */
#define PREVIEW_X 22 /* ̸ X ǥ. */
#define PREVIEW_Y 2 /* ̸ Y ǥ. */
#define INFO_X 22 /*   X ǥ. */
#define INFO_Y 7 /*   Y ǥ. */
#define HELP_X 22 /*  HELP X ǥ. */
#define HELP_Y 19 /*  HELP Y ǥ. */
#define MY_TABLE_X 2 /*   ̺ X ǥ. */
#define MY_TABLE_Y 2 /*   ̺ Y ǥ. */
#define ENEMY_TABLE_X 34 /*   ̺ X ǥ. */
#define ENEMY_TABLE_Y 2 /*    Y ǥ. */
#define MENU_X 1 /*  ޴ X ǥ. */
#define MENU_Y 1 /*  ޴ Y ǥ. */
#define MAX_NAME 13 /* ְ  ִ ̸ . */
#define MAX_SCORE_LIST 10 /* ְ  . */
#define DEFAULT_PORT 8161 /* ⺻ Ʈ. */
#define MAX_BUFFER 30 /* ӽ  . */
#define SINGLE_GAMEOVER 0 /*  . */
#define NETWORK_PLAY 0 /* . */
#define NETWORK_WIN 1 /* ¸. */
#define NETWORK_LOSE 2 /* й. */
#define NETWORK_DRAW 3 /* . */
#define NETWORK_CONFIRM 4 /* Ȯ. */
#define SCORE_DATA SCORE_DATA_DIR"/""high_score" /* ְ  . */

/********************************
 * Symbols defined in network.c *
 ********************************/

void signal_handler(int signal_number); /* SIGARLM ڵ鷯. */

/*******************************
 * Symbols defined in common.c *
 *******************************/

void init_board(); /* 带 ʱȭ Ѵ. */
int  game_over(int status); /*   óѴ. */
void print_score(); /*  Ѵ. */
void print_level(); /*  Ѵ. */
void create_random_blocks(); /*    Ѵ. */
void preview_blocks(); /*    Ѵ. */
void draw_cur_blocks(); /*  ׸. */
void clear_cur_blocks(); /*   Ѵ. */
void rotate_blocks(); /*  ȸŲ. */
void set_block_to_board(); /*  忡 ׸. */
void move_blocks_right(); /*   ̵Ѵ. */
void move_blocks_down(); /*  Ʒ ̵Ѵ. */
void move_blocks_left(); /*   ̵Ѵ. */
void move_blocks_down_direct(); /*  Ʒ ѹ ̵Ѵ. */
void check_level(int); /*  üũѴ. */ 
void check_lines(); /*  üũѴ. */
void check_attack(); /*   浹 üũѴ. */
int check_collision(); /* 浹 ˻Ѵ. */
void draw_table(); /*  ̺ ׸. */
void draw_enemy_table(); /*   ̺ ׸. */
void draw_info(); /* ,  ׸. */
void draw_help(); /*   ޴ ׸. */
void draw_board(); /* ̺   ٽ ׸. */
void draw_enemy_board(); /*  ̺   ٽ ׸. */
int start_single_game(); /* ̱  Ѵ. */
int start_single_game_direct(int start_level); /* ̱  ٷ Ѵ. */
void pause_game(); /*  ϽѴ. */
char *get_value(char *message); /* ڿ Է¹޴´. */
int is_number(char *string); /* ڿ  ǴѴ. */
void error_handling(char *message); /*  ó. */

/*****************************
 * Symbols defined in menu.c *
 *****************************/

int show_main_menu(); /* ޴ Ѵ. */
int show_single_game_menu(); /* ̱۰ ޴ . */
int show_network_game_menu(); /* Ʈũ  ޴ . */
int show_game_intro(); /*  Ұ. */

/******************************
 * Symbols defined in score.c *
 ******************************/
typedef struct {
	int score;
	int level;
	char name[MAX_NAME];
} high_score;

int get_score_list(); /* ְ  ´. */
int check_score_list(int score, int level); /* ְ  ϴ üũѴ. */
high_score get_username(int score, int level); /* ְ  Ž  ̸ Է¹޴´. */
int put_score_list(); /* ְ  Ͽ . */
void show_score_list(); /* ְ  ش. */

/********************************
 * Symbols defined in network.c *
 ********************************/

int server_mode(); /*  . */
int client_mode(); /* Ŭ̾Ʈ . */
int server_mode_direct(unsigned short int port); /*   ٷ Ѵ. */
int client_mode_direct(char *server_address, unsigned short int port); /* Ŭ̾Ʈ  ٷ Ѵ. */
void *network_main(void *arg); /*  κ. */
void *network_receiver(void *arg); /* ͸ ֱ ޴´. */

typedef struct {
	int status;
	unsigned int attack_lines;
	char board[MAX_HEIGHT][MAX_WIDTH];
} packet;

#endif /* MAIN_H */

==> ttetris-0.1.4.tar.gz: ttetris-0.1.4/main.h <==
/****************************************************************
 Project Name: Terminal Tetris
 File Name: main.h
 Description: Լ .
 
 Created:2004. 12. 22  
 RCS-ID: $Id: main.h,v 1.50 2004/06/18 06:28:14 myunggoni Exp $
 Copyright: (c) 2004 by myunggoni
 License: GNU General Public License
 Author: Myung-Gon, Park <myunggoni@users.kldp.net>
 ***************************************************************/
#ifndef MAIN_H
#define MAIN_H

#define MAX_HEIGHT 21 /*  . */
#define MAX_WIDTH 17 /*  ʺ. */
#define START_BLOCKS_X 6 /*    ġ(). */
#define START_BLOCKS_Y 1 /*    ġ(). */
#define PREVIEW_X 22 /* ̸ X ǥ. */
#define PREVIEW_Y 2 /* ̸ Y ǥ. */
#define INFO_X 22 /*   X ǥ. */
#define INFO_Y 7 /*   Y ǥ. */
#define HELP_X 22 /*  HELP X ǥ. */
#define HELP_Y 19 /*  HELP Y ǥ. */
#define MY_TABLE_X 2 /*   ̺ X ǥ. */
#define MY_TABLE_Y 2 /*   ̺ Y ǥ. */
#define ENEMY_TABLE_X 34 /*   ̺ X ǥ. */
#define ENEMY_TABLE_Y 2 /*    Y ǥ. */
#define MENU_X 1 /*  ޴ X ǥ. */
#define MENU_Y 1 /*  ޴ Y ǥ. */
#define MAX_NAME 13 /* ְ  ִ ̸ . */
#define MAX_SCORE_LIST 10 /* ְ  . */
#define DEFAULT_PORT 8161 /* ⺻ Ʈ. */
#define DEFAULT_LEVEL 1 /* ⺻ . */
#define MAX_LEVEL 20 /* ְ . */
#define MAX_BUFFER 30 /* ӽ  . */
#define SINGLE_GAMEOVER 0 /*  . */
#define NETWORK_PLAY 0 /* . */
#define NETWORK_WIN 1 /* ¸. */
#define NETWORK_LOSE 2 /* й. */
#define NETWORK_DRAW 3 /* . */
#define NETWORK_CONFIRM 4 /* Ȯ. */
#define SCORE_DATA SCORE_DATA_DIR"/""high_score" /* ְ  . */

/********************************
 * Symbols defined in main.c *
 ********************************/

void print_usage(FILE *stream, int exit_code); /* ʸ Ѵ. */

/*******************************
 * Symbols defined in common.c *
 *******************************/

void init_board(); /* 带 ʱȭ Ѵ. */
int  game_over(int status); /*   óѴ. */
void print_score(); /*  Ѵ. */
void print_level(); /*  Ѵ. */
void create_random_blocks(); /*    Ѵ. */
void preview_blocks(); /*    Ѵ. */
void draw_cur_blocks(); /*  ׸. */
void clear_cur_blocks(); /*   Ѵ. */
void rotate_blocks(); /*  ȸŲ. */
void set_block_to_board(); /*  忡 ׸. */
void move_blocks_right(); /*   ̵Ѵ. */
void move_blocks_down(); /*  Ʒ ̵Ѵ. */
void move_blocks_left(); /*   ̵Ѵ. */
void move_blocks_down_direct(); /*  Ʒ ѹ ̵Ѵ. */
void check_level(int); /*  üũѴ. */ 
void check_lines(); /*  üũѴ. */
void check_attack(); /*   浹 üũѴ. */
int check_collision(); /* 浹 ˻Ѵ. */
void draw_table(); /*  ̺ ׸. */
void draw_enemy_table(); /*   ̺ ׸. */
void draw_info(); /* ,  ׸. */
void draw_help(); /*   ޴ ׸. */
void draw_board(); /* ̺   ٽ ׸. */
void draw_enemy_board(); /*  ̺   ٽ ׸. */
int start_single_game(); /* ̱  Ѵ. */
int start_single_game_direct(int start_level); /* ̱  ٷ Ѵ. */
void pause_game(); /*  ϽѴ. */
char *get_value(int y, int x, char *message); /* ڿ Է¹޴´. */
int is_number(char *string); /* ڿ  ǴѴ. */
void error_handling(char *message); /*  ó. */
void sigalrm_handler(int signal_number); /* SIGARLM ڵ鷯. */
void sigint_handler(int signal_number); /* SIGINT ڵ鷯. */
int set_signal_handler(); /* ñ׳ ڵ鷯 ġѴ. */
int set_timer(int flag); /* Ÿ̸Ӹ Ѵ. */

/*****************************
 * Symbols defined in menu.c *
 *****************************/

int show_main_menu(); /* ޴ Ѵ. */
int show_single_game_menu(); /* ̱۰ ޴ . */
int show_network_game_menu(); /* Ʈũ  ޴ . */
int show_game_intro(); /*  Ұ. */

/******************************
 * Symbols defined in score.c *
 ******************************/
typedef struct {
	int score;
	int level;
	char name[MAX_NAME];
} high_score;

int get_score_list(); /* ְ  ´. */
int check_score_list(int score, int level); /* ְ  ϴ üũѴ. */
high_score get_username(int score, int level); /* ְ  Ž  ̸ Է¹޴´. */
int put_score_list(int rank, int score, int level); /* ְ  Ͽ . */
void show_score_list(); /* ְ  ش. */

/********************************
 * Symbols defined in network.c *
 ********************************/

int server_mode(); /*  . */
int client_mode(); /* Ŭ̾Ʈ . */
int server_mode_direct(unsigned short int port, int start_level); /*   ٷ Ѵ. */
int client_mode_direct(char *server_address, unsigned short int port); /* Ŭ̾Ʈ  ٷ Ѵ. */
void *network_main(void *arg); /*  κ. */
void *network_receiver(void *arg); /* ͸ ֱ ޴´. */

typedef struct {
	int status;
	unsigned int attack_lines;
	char board[MAX_HEIGHT][MAX_WIDTH];
} packet;

#endif /* MAIN_H */
